%% creates force estimates from unfiltered data
clear inndata*

clear v
clear b
load 'alldataascii/inndata_2_3'
load 'alldataascii/inndata_3_3'
load 'alldataascii/inndata_1_2'
load 'alldataascii/utdata_2_3'
load 'alldataascii/utdata_3_3'
load 'alldataascii/utdata_1_2'

%% Create first order estimation
for l=1:4
   if l<4
       [F_eu(:,l),Fval_eu(:,l),Ftest_eu(:,l)] = FirstOrderEstimation(length(inndata_2_3),length(inndata_3_3), length(inndata_1_2),1,inndata_2_3(:,l),utdata_2_3,inndata_3_3(:,l),utdata_3_3,inndata_1_2(:,l),utdata_1_2); 
        F_eu(:,l) = smooth(F_eu(:,l),10);
        Fval_eu(:,l) = smooth(Fval_eu(:,l),10);
        Ftest_eu(:,l) = smooth(Ftest_eu(:,l),10);      
   else
       [F_eu(:,l),Fval_eu(:,l),Ftest_eu(:,l)] = FirstOrderEstimation(length(inndata_2_3),length(inndata_3_3), length(inndata_1_2),4,inndata_2_3,utdata_2_3,inndata_3_3,utdata_3_3,inndata_1_2,utdata_1_2);
        F_eu(:,l) = smooth(F_eu(:,l),10);
        Fval_eu(:,l) = smooth(Fval_eu(:,l),10);
        Ftest_eu(:,l) = smooth(Ftest_eu(:,l),10); 
   end
end


%% Create second order estimation
for l=1:4
   if l<4
        [F2_eu(l,:),F2val_eu(l,:),F2test_eu(l,:)] = secondOrderEstimation(length(inndata_2_3),length(inndata_3_3), length(inndata_1_2),1,inndata_2_3(:,l)',utdata_2_3',inndata_3_3(:,l)',utdata_3_3',inndata_1_2(:,l)',utdata_1_2');
        F2_eu(l,:) = smooth(F2_eu(l,:),10);
        F2val_eu(l,:) = smooth(F2val_eu(l,:),10);
        F2test_eu(l,:) = smooth(F2test_eu(l,:),10);  
   else
        [F2_eu(l,:),F2val_eu(l,:),F2test_eu(l,:)] = secondOrderEstimation(length(inndata_2_3),length(inndata_3_3), length(inndata_1_2),4,inndata_2_3',utdata_2_3',inndata_3_3',utdata_3_3',inndata_1_2',utdata_1_2');
        F2_eu(l,:) = smooth(F2_eu(l,:),10);
        F2val_eu(l,:) = smooth(F2val_eu(l,:),10);
        F2test_eu(l,:) = smooth(F2test_eu(l,:),10); 
   end
end
F2_eu = F2_eu';
F2val_eu = F2val_eu';
F2test_eu = F2test_eu';

%% Create GP-based estimation
load v_400_2600_u.mat;
b = v.state.bestsofar;
Fgp_eu = smooth(str2num(evaluate_tree(b.tree,inndata_2_3)),10);
Fgpval_eu = smooth(str2num(evaluate_tree(b.tree,inndata_3_3)),10);
Fgptest_eu = smooth(str2num(evaluate_tree(b.tree,inndata_1_2)),10);


clear l;
%%Run 50 Neural Networks and select the best for use :)
%%
if trainnet == 1;
    best_rmseu = 999999;
    for k =1:50
        [Fn_eu,Fnval_eu,Fntest_eu, netu] = neuralNetwork(length(inndata_2_3),length(inndata_3_3), length(inndata_1_2),4,1,inndata_2_3',utdata_2_3',inndata_3_3',utdata_3_3','tansig',4,inndata_1_2',utdata_1_2',0);
        rmseu = rmsError(Fn_eu,utdata_2_3');
        if k ==1
            best_rmseu = rmseu;
        end
        if rmseu < best_rmseu
            best_rmseu = rmseu;
            best_netu = netu;
        end
    end
end
%%
%No need to train network when we already have one
if trainnet == 0
    load best_netu
    Fn_eu = smooth(sim(best_netu,inndata_2_3')',10);
    Fnval_eu = smooth(sim(best_netu,inndata_3_3')',10);
    Fntest_eu = smooth(sim(best_netu,inndata_1_2')',10);
end
F_eu(:,5) = utdata_2_3;
Fval_eu(:,5) = utdata_3_3;
Ftest_eu(:,5) = utdata_1_2;
F2_eu(:,5) = utdata_2_3;
F2val_eu(:,5) = utdata_3_3;
F2test_eu(:,5) = utdata_1_2;

%% Plot and save plots
if(plotfig==1)
    %%Plot and save train data
    t = 0:0.025:(length(inndata_2_3)*0.025-0.025);
    figure;
    ylim([-0.5 4])
    hold all;
    plot(t',F_eu(:,4),':', t',F2_eu(:,4),'--',t', Fn_eu',t',Fgp_eu, t',F_eu(:,5),'g',t,inndata_2_3(:,4)');
    legend('1.ordens','2. ordens','Nevralt nett','GP','Maaling','Kontaktkraft')
    title('Treningsdata')
    set(gcf, 'PaperUnits', 'centimeters');
    set(gcf, 'PaperSize', [20 5]);
    set(gcf, 'PaperPosition', [0 0 20 5]);
    if saveit ==1
        saveas(gcf,'plots/F_trainu.pdf','pdf')
    end
    
    %%Plot and save test data
    t = 0:0.025:(length(inndata_3_3)*0.025-0.025);
    figure;
    ylim([-0.5 4])
    hold all;
    plot(t,Fval_eu(:,4),':', t,F2val_eu(:,4),'--',t, Fnval_eu',t,Fgpval_eu, t,Fval_eu(:,5),'g',t,inndata_3_3(:,4)');
    legend('1.ordens','2. ordens','Nevralt nett','GP','Maaling','Kontaktkraft')
    title('Valideringsdata')
    set(gcf, 'PaperUnits', 'centimeters');
    set(gcf, 'PaperSize', [20 5]);
    set(gcf, 'PaperPosition', [0 0 20 5]);
    if saveit ==1
        saveas(gcf,'plots/F_valu.pdf','pdf')
    end
    
    %%Plot and save validataion data
    t = 0:0.025:(length(inndata_1_2)*0.025-0.025);
    figure;
    ylim([-0.5 4])
    hold all;
    plot(t,Ftest_eu(:,4),':', t,F2test_eu(:,4),'--',t, Fntest_eu',t,Fgptest_eu, t,Ftest_eu(:,5),'g',t,inndata_1_2(:,4)');
    legend('1.ordens','2. ordens','Nevralt nett','GP','Maaling','Kontaktkraft')
    title('Testdata');
    set(gcf, 'PaperUnits', 'centimeters');
    set(gcf, 'PaperSize', [20 5]);
    set(gcf, 'PaperPosition', [0 0 20 5]);
    if saveit ==1
        saveas(gcf,'plots/F_testu.pdf','pdf')
    end
end