function [F_e,Fval_e,Ftest_e,net] = neuralNetwork(Tdata,Tval,Ttest,Nx,Nf,Xdata,Fdata,Xvaldata,Fvaldata,TfChoice,HiddenNodes,Xtestdata,Ftestdata,testNet)
% neuralNetwork  Uses neural network theory to find a relation
% between a signal matrix X (for N signals and T time steps) and a function
% matrix F.
%Nx number of Nx signals
%Nf Nf output signals
%Hiddennodes _nr of hidden nodes_
% tfchoice -> 'tansig','logsig','purelin');
% run = 50
% nodes = 10 
%Then it generates an estimate F_e of the function matrix F, using the
% neural net.
%
% Finally, the function returns F_e, which is the estimate of F, and
% according results for validation and test sets.
%
%
% See also MAKEDATA, FIRSTORDERESTIMATION, SECONDORDERESTIMATION

% Anders Fougner, anderfo@stud.ntnu.no
% $Revision: 2.0 $Date: 2007/05/20 22:13:00 $
% Modified 2009/12/1 Simen Farstad simenaf@stud.ntnu.no

%get NX and NF
Nx = size(Xdata,1);
Nf = size(Fdata,1);   

% "Normalization/standardization" of output data
[Fdata2,FdataS] = mapminmax(Fdata);
[Fvaldata2,FvaldataS] = mapminmax(Fvaldata);
[Ftestdata2,FtestdataS] = mapminmax(Ftestdata);

% Choice of transfer function in the nodes/synapses of the NN

Tfs(1:HiddenNodes,1:Nf) = {TfChoice}; % tansig is default
disp(['Using ' num2str(HiddenNodes) ' nodes in the hidden layer.']);


% Generate a neural network

    net = newff(minmax(Xdata),minmax(Fdata),[HiddenNodes Nf],Tfs);

    % Make validation and testing structures
    VV.P = Xvaldata;
    VV.T = Fvaldata2;


TV.P = Xtestdata;
TV.T = Ftestdata2;


    % Train the neural network, but do not print error messages
    net.trainParam.showWindow = false;
    net.trainParam.show = 1;
    %[net,tr]=train(net,Xdata,Fdata2,[],[],VV,TV);
    net = train(net,Xdata,Fdata);
    % Simulate Xdata and Xvaldata in the NN to estimate F and Fval
    F_e = sim(net,Xdata);
    Fval_e = sim(net,Xvaldata);
    Ftest_e = sim(net,Xtestdata);
if testNet
    net = testNet;
end