function EMGout = e_amp_wh(EMGin, EMGinfo)
%E_AMP_WH Private global function to perform whitening.
%
% EMG Amplitude Estimation Toolbox - Ted Clancy - WPI

% Copyright (c) Edward A. Clancy, 2007.
% This work is licensed under the Aladdin free public license.
% For copying permissions see license.txt.
% email: ted@wpi.edu

% 5 February 2007.

[Erow, Ecol] = size(EMGin);

switch EMGinfo.WhiteFlag
  case 'On'
    % Make first-pass amplitude estimate based on EMGin (which is already
    %   high pass filtered and should not be whitened).
    Eamp1 = e_amp_un(EMGin, EMGinfo);
    Eamp1 = e_amp_dm(Eamp1, EMGinfo);
    Eamp1 = e_amp_sm(Eamp1, EMGinfo);
    Eamp1 = e_amp_rl(Eamp1, EMGinfo);
    % Now, adaptively whiten.
    for i = 1:EMGinfo.Channels
      if Erow>Ecol
        EMGout(:,i) = e_whiten(EMGin(:,i), EMGinfo.WhiteB{i}, EMGinfo.White_sCalVec{i}, ...
             Eamp1, EMGinfo.Causality, EMGinfo.WhiteEdges, EMGinfo.WhiteSum);
      else
        EMGout(i,:) = e_whiten(EMGin(i,:), EMGinfo.WhiteB{i}, EMGinfo.White_sCalVec{i}, ...
             Eamp1, EMGinfo.Causality, EMGinfo.WhiteEdges, EMGinfo.WhiteSum);
      end
    end
  case 'Off'
    EMGout = EMGin;
  otherwise, error(['Bogus "WhiteFlag" = "' EMGinfo.WhiteFlag '".']);
end
