function [EMGamp HpassWn] = e_amp(EMGin, SLin, EMGinfo)
%E_AMP Perform a complete EMG amplitude estimate.
%
% EMGamp = e_amp(EMGin, EMGinfo)
%
% EMG Amplitude Estimation Toolbox - Ted Clancy - WPI

% Copyright (c) Edward A. Clancy, 2007.
% This work is licensed under the Aladdin free public license.
% For copying permissions see license.txt.
% email: ted@wpi.edu

% 5 February 2007

%%%%%%%%%%%%%%%%%%%%% Process Command Line %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin~=3, error(['Bogus argument count (' int2str(nargin) '), expected 3']); end
if ischar(EMGin) == 1, error('Argument 1 must be numeric.'); end
if ndims(EMGin)>2, error('Argument 1 must be a matrix or vector.'); end

% Check that EMGin has the number of channels specified within EMGinfo.
[Erow, Ecol] = size(EMGin);
if Erow==Ecol, error('Argument 1 must not be a square matrix'); end
if Erow>Ecol, Channels=Ecol; else Channels=Erow; end
if Channels~=EMGinfo.Channels
  error('Channels in arg 1 must match channels in structure arg 2.');
end

%%%%%%%%%%%%%%%%%%%%%%%%%% Process %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Noise Rejection/Filtering.
 [EMGamp HpassWn] = e_amp_nj(EMGin, SLin, EMGinfo);
%EMGamp = EMGin;

% Whiten (in place).
EMGamp = e_amp_wh(EMGamp, EMGinfo);

% Multiple-Channel Combination (Including Gain Scaling).
 EMGamp = e_amp_un(EMGamp, EMGinfo);

% Demodulation.
EMGamp = e_amp_dm(EMGamp, EMGinfo);

% Smoothing.
EMGamp = e_amp_sm(EMGamp, EMGinfo);

% Relinearization.
EMGamp = e_amp_rl(EMGamp, EMGinfo);
