function EMGout = e_detect(EMGin, M)
%E_DETECT Apply power-law detector. 
%
% EMGout = e_detect(EMGin [, M])
%
% e_detect performs the detection step of EMG amplitude estimation.
% The detector step rectifies the EMG and then raises the signal to
% the power M. If M is not supplied or equal to the null value, the
% power M=1 is used by default.  EMGin is a matrix (or vector) of EMG
% samples. Output EMGout has the same dimensions as EMGin.
%
% EMG Amplitude Estimation Toolbox - Ted Clancy - WPI

% Copyright (c) Edward A. Clancy, 2007.
% This work is licensed under the Aladdin free public license.
% For copying permissions see license.txt.
% email: ted@wpi.edu

% 5 February 2007.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Check Command Line %%%%%%%%%%%%%%%%%%%%%%%%%%%
if (nargin<1 | nargin>2), error(['Bogus argument count (' int2str(nargin) '), expected 1-2']); end
if ischar(EMGin) == 1, error('Argument 1 must be numeric.'); end
if nargin == 1  |  isempty(M), M = 1; end
if ischar(M) == 1, error('Argument 2 must be numeric.'); end
if sum(size(M))>2, error('Argument 2 must be a scalor.'); end
if M<=0, error('Second argument must be > 0.'); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Process %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
EMGout = abs(EMGin) .^ M;
