function EMGampOut = e_relin(EMGampIn, M)
%E_RELIN Relinearize the EMG.
%
% EMGampOut = e_relin(EMGampIn [, M])
%
% e_relin performs the relinearization step of EMG amplitude estimation.
% The relinearization step "inverts" the detector power-law step by
% raising the input EMG amplitude to the power (1/M). If M is not supplied
% or specified as the null value, the power M=1 is used by default
% (i.e. the input signal is simply transferred to the output). EMGampIn
% is a matrix (or vector) of EMG samples.  Output EMGampOut has the same
% dimensions as EMGampIn.
%
% EMG Amplitude Estimation Toolbox - Ted Clancy - WPI

% Copyright (c) Edward A. Clancy, 2007.
% This work is licensed under the Aladdin free public license.
% For copying permissions see license.txt.
% email: ted@wpi.edu

% 5 February 2007.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Check Command Line %%%%%%%%%%%%%%%%%%%%%%%%%%%
if (nargin<1 | nargin>2), error(['Bogus argument count (' int2str(nargin) '), expected 1-2']); end
if ischar(EMGampIn) == 1, error('Argument 1 must be numeric.'); end
if nargin == 1  |  isempty(M), M = 1; end
if ischar(M) == 1, error('Argument 2 must be numeric.'); end
if sum(size(M))>2, error('Argument 2 must be a scalor.'); end
if M<=0, error('Second argument must be > 0.'); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Process %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
EMGampOut = EMGampIn .^ (1/M);
