function EMGout = e_uncorr(EMGin, Hspace)
%E_UNCORR Spatially uncorrelate and gain normalize multiple-site EMG data.
%
% EMGout = e_uncorr(EMGin, Hspace)
%
% EMGin: Matrix of L vectors, each vector being the N time-series data
%        samples from one whitened EMG signal.  The larger of the two
%        matrix dimensions is assigned as the sample index, the smaller
%        the channel index; ties produce an error.
% Hspace: Square spatial uncorrelation matrix as calibrated by e_cal_sp().
%        Each ROW holds the coefficients used to produce one output
%        channel when spatial uncorrelation is applied.
%
% EMGout: Spatially filtered output EMG, same dimensions as EMGin.
%
% EMG Amplitude Estimation Toolbox - Ted Clancy - WPI

% Copyright (c) Edward A. Clancy, 2007.
% This work is licensed under the Aladdin free public license.
% For copying permissions see license.txt.
% email: ted@wpi.edu

% 5 February 2007.

% L: Number of EMG channels.

%%%%%%%%%%%%%%%%%%%%% Process Command Arguments %%%%%%%%%%%%%%%%%%%%%

% Check number of input arguments
if nargin~=2, error(['Expected 2 arguments, found ' int2str(nargin) '.']); end

% Check EMGin
if ischar(EMGin), error('Argument 1 must be numeric.'); end
if ndims(EMGin)>2, error('Argument 1 must be a matrix.'); end
[Erow, Ecol] = size(EMGin);
if Erow==Ecol, error('Argument 1 can not be a square matix.'); end
if Erow>Ecol, L = Ecol; else L = Erow; end

% Check Hspace.
if ischar(Hspace), error('Argument 2 must be numeric.'); end
if ndims(Hspace)~=2, error('Argument 2 must be a matrix.'); end
[Hrow, Hcol] = size(Hspace);
if (Hrow~=L | Hcol~=L), error('Wrong dimensions for arg 2.'); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Compute %%%%%%%%%%%%%%%%%%%%%%%%%

% Compute covariance matrix.
if Erow>Ecol
  EMGout = EMGin * Hspace';
else
  EMGout = Hspace * EMGin;
end
